var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from 'react';
import { listHelpers } from 'redux-admin';
import { getDeepObjectValue } from 'validate.js';
import { getFieldName } from './utils.js';

var EMPTY_OBJ = {};

var DEFAULT_FIELDS = ['_id', 'createdAt', 'updatedAt'];

var getListFields = function getListFields(_ref) {
  var rtl = _ref.rtl,
      lang = _ref.lang;
  var jsonSchema = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var dashboardConfig = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var filtersData = arguments[3];

  var properties = jsonSchema.properties || EMPTY_OBJ;
  var fields = [];
  Object.keys(properties).forEach(function (itemKey) {
    var item = properties[itemKey];
    var meta = getDeepObjectValue(item, 'meta.0') || EMPTY_OBJ;
    if ((item.type === 'object' || item.type === Object) && meta === EMPTY_OBJ) {
      // in this case the meta can be found at the children as parentDashboard, this is a workaround;
      var metaFromInnerField = void 0;
      Object.keys(item.properties).forEach(function (itemKey) {
        if (!metaFromInnerField) {
          var innerField = item.properties[itemKey];
          metaFromInnerField = getDeepObjectValue(innerField, 'meta.0.parentDashboard');
        }
      });
      if (metaFromInnerField) {
        meta = { dashboard: metaFromInnerField };
      }
    }
    var dashboard = getDeepObjectValue(meta, 'dashboard') || EMPTY_OBJ;
    var dashboardList = getDeepObjectValue(meta, 'dashboard.list') || EMPTY_OBJ;
    var dashboardConfigDefaultFields = dashboardConfig.defaultFieldsToDisplay;
    var type = item.type;

    if (item.format === 'date-time') type = Date;
    if (meta.ref) {
      type = Object;
    }

    var fieldConfig = {
      key: itemKey,
      title: getFieldName({ target: 'list', lang: lang, itemKey: itemKey, dashboardList: dashboardList, dashboard: dashboard, dashboardConfig: dashboardConfig }),
      type: dashboardList.type || type,
      sorter: dashboardList.sorter === false ? false : dashboardList.sorter || true,
      width: dashboardList.width,
      labelKey: meta.displayKey,
      dateFormat: dashboardList.dateFormat,
      forceLtr: dashboardList.forceLtr
    };

    if (dashboardList.options) {
      fieldConfig.render = function (cal) {
        if (dashboardList.options) {
          var valueFromOptions = dashboardList.options.find(function (option) {
            return option.value === cal;
          });
          if (valueFromOptions) {
            var valueToDisplay = valueFromOptions.i18nLabels && valueFromOptions.i18nLabels[lang] || valueFromOptions.label;
            return valueToDisplay || cal;
          }
        }
        return cal;
      };
    }
    if (dashboard.hide || dashboardList.hide || dashboardConfigDefaultFields && DEFAULT_FIELDS.includes(itemKey) && !dashboardConfigDefaultFields.includes(itemKey)) {
      fieldConfig.hideFromTable = true;
    }
    var fieldToPush = _extends({}, listHelpers.getListField(fieldConfig), {
      hideFromTable: fieldConfig.hideFromTable,
      align: dashboardConfig.listFieldAlign || 'right'
    });
    if (filtersData) {
      fieldToPush.label = fieldConfig.title;
      if (dashboardList.options) {
        fieldToPush.options = dashboardList.options.map(function (option) {
          var filterOption = _extends({}, option);
          filterOption.label = filterOption.i18nLabels && filterOption.i18nLabels[lang] || filterOption.label;
          return filterOption;
        });
      }
    }
    fields.push(fieldToPush);
  });
  return fields;
};
export default getListFields;